==> qt-creator-opensource-src-4.10.2.zip: qt-creator-opensource-src-4.10.2/src/plugins/baremetal/keilparser.h <==
/****************************************************************************
**
** Copyright (C) 2019 Denis Shienkov <denis.shienkov@gmail.com>
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectexplorer/ioutputparser.h>
#include <projectexplorer/task.h>

namespace BareMetal {
namespace Internal {

// KeilParser

class KeilParser final : public ProjectExplorer::IOutputParser
{
    Q_OBJECT

public:
    explicit KeilParser();
    static Core::Id id();

private:
    void newTask(const ProjectExplorer::Task &task);
    void amendDescription(const QString &desc);

    void stdError(const QString &line) final;
    void stdOutput(const QString &line) final;
    void doFlush() final;

    ProjectExplorer::Task m_lastTask;
    int m_lines = 0;
};

} // namespace Internal
} // namespace BareMetal

==> qt-creator-opensource-src-4.11.0.zip: qt-creator-opensource-src-4.11.0/src/plugins/baremetal/keilparser.h <==
/****************************************************************************
**
** Copyright (C) 2019 Denis Shienkov <denis.shienkov@gmail.com>
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectexplorer/ioutputparser.h>
#include <projectexplorer/task.h>

namespace BareMetal {
namespace Internal {

// KeilParser

class KeilParser final : public ProjectExplorer::IOutputParser
{
    Q_OBJECT

public:
    explicit KeilParser();
    static Core::Id id();

private:
    void newTask(const ProjectExplorer::Task &task);
    void amendDescription();

    // ARM compiler specific parsers.
    bool parseArmWarningOrErrorDetailsMessage(const QString &lne);
    bool parseArmErrorOrFatalErorrMessage(const QString &lne);

    // MCS51 compiler specific parsers.
    bool parseMcs51WarningOrErrorDetailsMessage1(const QString &lne);
    bool parseMcs51WarningOrErrorDetailsMessage2(const QString &lne);
    bool parseMcs51WarningOrFatalErrorMessage(const QString &lne);
    bool parseMcs51FatalErrorMessage2(const QString &lne);

    void stdError(const QString &line) final;
    void stdOutput(const QString &line) final;
    void doFlush() final;

    ProjectExplorer::Task m_lastTask;
    int m_lines = 0;
    QStringList m_snippets;
};

} // namespace Internal
} // namespace BareMetal
